



dir %PREFIX%\Library\bin\*
IF %ERRORLEVEL% NEQ 0 exit /B 1
dir %PREFIX%\Library\lib\*
IF %ERRORLEVEL% NEQ 0 exit /B 1
icpx -fsycl simple.cpp -I%PREFIX%\include -o simple.exe
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
